Crate dezoomify_rs

Crate dezoomify_rs 

Modules

auto
Automatic format detection and metadata resolution.
bulk_text
custom_yaml
dezoomer
Types for discovering logical images and their tiled resolution levels.
dzi
generic
google_arts_and_culture
iiif
iipimage
krpano
nypl
pff
tile
zoomify

Structs

Arguments
BinaryDisplay
A wrapper struct to display binary data in a Python-like format
BulkStats
Statistics for bulk processing
Vec2d

Enums

ZoomError

Functions

dezoomify
Downloads the image selected by args and returns its output path.
dezoomify_level
Downloads and encodes one zoom level into tile_buffer.
display_bytes
Convenience function to create a BinaryDisplay wrapper
max_size_in_rect
Returns the maximal size a tile can have in order to fit in a canvas of the given size
process_bulk
Process every image discovered from a bulk input.