Modules
- auto
- Automatic format detection and metadata resolution.
- bulk_
text - custom_
yaml - dezoomer
- Types for discovering logical images and their tiled resolution levels.
- dzi
- generic
- google_
arts_ and_ culture - iiif
- iipimage
- krpano
- nypl
- pff
- tile
- zoomify
Structs
- Arguments
- Binary
Display - A wrapper struct to display binary data in a Python-like format
- Bulk
Stats - Statistics for bulk processing
- Vec2d
Enums
Functions
- dezoomify
- Downloads the image selected by
argsand returns its output path. - dezoomify_
level - Downloads and encodes one zoom level into
tile_buffer. - display_
bytes - Convenience function to create a
BinaryDisplaywrapper - max_
size_ in_ rect - Returns the maximal size a tile can have in order to fit in a canvas of the given size
- process_
bulk - Process every image discovered from a bulk input.