[−][src]Struct dezoomify_rs::Arguments
Fields
input_uri: Option<String>Input URL or local file name
outfile: Option<PathBuf>File to which the resulting image should be saved
largest: boolIf several zoom levels are available, then select the largest one
parallelism: usizeDegree of parallelism to use. At most this number of tiles will be downloaded at the same time.
retries: usizeNumber of new attempts to make when a tile load fails before giving up. Setting this to 0 is useful to speed up the generic dezoomer, which relies on failed tile loads to detect the dimensions of the image. On the contrary, if a server is not reliable, set this value to a higher number.
retry_delay: DurationAmount of time to wait before retrying a request that failed. Applies only to the first retry. Subsequent retries follow an exponential backoff strategy: each one is twice as long as the previous one.
compression: u8A number between 0 and 100 expressing how much to compress the output image. For lossy output formats such as jpeg, this affects the quality of the resulting image. 0 means less compression, 100 means more compression. Currently affects only the JPEG and PNG encoders.
headers: Vec<(String, String)>Sets an HTTP header to use on requests.
This option can be repeated in order to set multiple headers.
You can use -H "Referer: URL" where URL is the URL of the website's
viewer page in order to let the site think you come from the legitimate viewer.
max_idle_per_host: usizeMaximum number of idle connections per host allowed at the same time
accept_invalid_certs: boolWhether to accept connecting to insecure HTTPS servers
timeout: DurationMaximum time between the beginning of a request and the end of a response before the request should be interrupted and considered failed
connect_timeout: DurationTime after which we should give up when trying to connect to a server
logging: StringLevel of logging verbosity. Set it to "debug" to get all logging messages.
Implementations
impl Arguments[src]
pub fn choose_input_uri(&self) -> Result<String, ZoomError>[src]
pub fn find_dezoomer(&self) -> Result<Box<dyn Dezoomer>, ZoomError>[src]
pub fn best_size<I: Iterator<Item = Vec2d>>(&self, sizes: I) -> Option<Vec2d>[src]
pub fn headers(&self) -> impl Iterator<Item = (&String, &String)>[src]